"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const useCioClient_1 = tslib_1.__importDefault(require("./useCioClient"));
const useConsoleErrors_1 = tslib_1.__importDefault(require("./useConsoleErrors"));
const useQuizApiState_1 = tslib_1.__importDefault(require("./useQuizApiState"));
const useQuizEvents_1 = tslib_1.__importDefault(require("./useQuizEvents"));
const useQuizLocalState_1 = tslib_1.__importDefault(require("./useQuizLocalState"));
const useQuiz = ({ quizId, apiKey, cioJsClient, quizVersionId, resultsPageOptions }) => {
    // Log console errors for required parameters quizId and resultsPageOptions
    (0, useConsoleErrors_1.default)(quizId, resultsPageOptions);
    // Quiz Local state
    const { quizLocalState, resetQuizLocalState, dispatchLocalState } = (0, useQuizLocalState_1.default)();
    // Quiz Cio Client
    const cioClient = (0, useCioClient_1.default)({ apiKey, cioJsClient });
    // Quiz API state
    const { isFirstQuestion, quizApiState, resetQuizApiState } = (0, useQuizApiState_1.default)(quizId, quizLocalState, resultsPageOptions, quizVersionId, cioClient);
    // Quiz callback events
    const quizEvents = (0, useQuizEvents_1.default)({
        cioClient,
        quizApiState,
        resultsPageOptions,
        dispatchLocalState,
        resetQuizApiState,
        resetQuizLocalState,
    });
    return {
        cioClient,
        state: {
            answers: {
                inputs: quizLocalState.answerInputs,
                isLastAnswer: quizLocalState.isLastAnswer,
            },
            quiz: {
                requestState: quizApiState.quizRequestState,
                versionId: quizApiState.quizVersionId,
                sessionId: quizApiState.quizSessionId,
                firstQuestion: quizApiState.quizFirstQuestion,
                currentQuestion: quizApiState.quizCurrentQuestion,
                results: quizApiState.quizResults,
                resultsFilters: quizApiState.quizResultsFilters,
                isFirstQuestion,
            },
        },
        events: Object.assign({}, quizEvents),
    };
};
exports.default = useQuiz;
